"""NapCat 适配器专用常量。"""

# ==================== 目录路径 ====================

WINDOWS_NAPCAT_DIR = "napcat"
LINUX_NAPCAT_DIR = "/opt/QQ/resources/app/app_launcher/napcat"

# ==================== URL ====================

INSTALL_SCRIPT_URL = (
    "https://nclatest.znin.net/NapNeko/NapCat-Installer/main/script/install.sh"
)
NAPCAT_CLI_URL = (
    "https://nclatest.znin.net/NapNeko/NapCat-Installer/main/script/napcat_cli"
)
PYPI_URL = "https://mirrors.aliyun.com/pypi/simple/"

# ==================== 认证 ====================

NAPCAT_WEBUI_SALT = "napcat"
